==> aprs4r-1.0.3.99.rc3.tar.gz: aprs4r-1.0.3.99.rc3/src/aprs4r/ISSocketConfiguration.rb <==
#
#  APRS4R - a ruby based aprs gateway/digipeater
#  Copyright (C) 2006 by Michael Conrad <do5mc@aprs4r.org>
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
#

require 'aprs4r/SocketConfiguration'
require 'aprs4r/ConfigurationAttribute'


module APRS4R

  class ISSocketConfiguration < SocketConfiguration

    attr_accessor :hosts, :port, :username, :filter, :duplicatePeriod, :txEnable, :timeout

    def to_yaml_properties
      super + %w{ @hosts @port @username @filter @duplicatePeriod @txEnable @timeout}
    end


    def attributes
      attributes = [
                    ConfigurationAttribute.new( "hosts",           "array",   true, 30, ["germany.aprs2.net", "swiss.aprs.net", "dl.aprs2.net"], "Hostname"),
                    ConfigurationAttribute.new( "port",            "number",  true,  6, 14580,             "Portnummer"),
                    ConfigurationAttribute.new( "username",        "text",    true, 10, "MYCALL",          "Benutzer"),
                    ConfigurationAttribute.new( "filter",          "text",    true, 20, "# filter m/50",   "Filter"),
                    ConfigurationAttribute.new( "duplicatePeriod", "number",  true, 10, 15,                "Duplikatsinterval"),
                    ConfigurationAttribute.new( "txEnable",        "boolean", true, 10, false,             "TX-Modus"),
                    ConfigurationAttribute.new( "timeout",         "number",  true,  6, 300,               "Timeout")
                   ]

      return super + attributes 
    end

  end

end

==> aprs4r-1.0.4.tar.gz: aprs4r-1.0.4/src/aprs4r/ISSocketConfiguration.rb <==
#
#  APRS4R - a ruby based aprs gateway/digipeater
#  Copyright (C) 2006 by Michael Conrad <do5mc@aprs4r.org>
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
#

require 'aprs4r/SocketConfiguration'
require 'aprs4r/ConfigurationAttribute'


module APRS4R

  class ISSocketConfiguration < SocketConfiguration

    attr_accessor :hosts, :port, :username, :filter, :duplicatePeriod, :txEnable, :timeout

    def to_yaml_properties
      super + %w{ @hosts @port @username @filter @duplicatePeriod @txEnable @timeout}
    end


    def attributes
      attributes = [
                    ConfigurationAttribute.new( "hosts",           "array",   true, 30, ["germany.aprs2.net", "swiss.aprs.net", "dl.aprs2.net"], "Hostname"),
                    ConfigurationAttribute.new( "port",            "number",  true,  6, 14580,             "Portnummer"),
                    ConfigurationAttribute.new( "username",        "text",    true, 10, "MYCALL",          "Benutzer"),
                    ConfigurationAttribute.new( "filter",          "text",    true, 20, "# filter m/50",   "Filter"),
                    ConfigurationAttribute.new( "duplicatePeriod", "number",  true, 10, 15,                "Duplikatsinterval"),
                    ConfigurationAttribute.new( "txEnable",        "boolean", true, 10, false,             "TX-Modus"),
                    ConfigurationAttribute.new( "timeout",         "number",  true,  6, 300,               "Timeout")
                   ]

      return super + attributes 
    end


    def update_configuration( old_version, new_version) 

      update = false 
      output = Array.new

      current_version = old_version

      # init, if no version is set
      if current_version.nil? || current_version == "undefined" 
        current_version = "1.0.0"
        update = true
      end

      # update to 1.0.1, nothing to do
      if current_version == "1.0.0" 
        current_version = "1.0.1" 
        update = true 
      end
      
      # update to 1.0.2, nothing to do
      if current_version == "1.0.1"
        current_version = "1.0.2" 
        update = true 
      end
      
      # update to 1.0.3, nothing to do 
      if current_version == "1.0.2"
        current_version = "1.0.3" 
        update = true
      end

      
      # update to 1.0.4, add txEnable flag
      if current_version == "1.0.3"
        current_version = "1.0.4"
        update = true
      end

      if current_version == "1.0.4"
        
        # check txEnable flag
        if @txEnable.nil?
          output.push( "ISSocket: add txEnable flag, setting to true\n")
          update = true 

          @txEnable = true
        end

      end
      
      
      return [ update, output]
    end

  end

end
